@@ -3,7 +3,7 @@
 
 from .data import Metadata
 from .wcat import query as qwcat
-from .googlebooks import query as qgoob
+from .goob import query as qgoob
 from . import vias
 from .. import config
 
@@ -26,8 +26,8 @@ def query(isbn, processor='parallel'):
 
     if md and rg:
         md.merge(rg, ('Authors'))
-        return md.canonical
+        return md.value
     if not md and rg:
         md = Metadata(rg)
-        return md.canonical
-    return md.canonical if not rg and rw else None
+        return md.value
+    return md.value if not rg and rw else None
