@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 from .dev import wcat
-from .dev import googlebooks
+from .dev import goob
 from .dev import merge
 from .dev import isbndb
 from .dev import openl
@@ -13,7 +13,7 @@ Config file for metadata services
 """
 services = {'default': merge.query,      # <-- mandatory
             'wcat': wcat.query,
-            'goob': googlebooks.query,
+            'goob': goob.query,
             'merge': merge.query,
             'isbndb': isbndb.query,
             'openl': openl.query,
